@@ -11,9 +11,8 @@ import git_machete.options
 from git_machete import __version__
 from git_machete import utils
 from git_machete.client import MacheteClient
-from git_machete.generated_long_docs import long_docs
-from git_machete.handmade_short_docs import short_docs
-from git_machete.exceptions import MacheteException, StopInteraction
+from git_machete.generated_docs import short_docs, long_docs
+from git_machete.exceptions import ExitCode, MacheteException, StopInteraction
 from git_machete.git_operations import AnyBranchName, AnyRevision, GitContext, LocalBranchShortName, RemoteBranchShortName
 from git_machete.utils import bold, fmt, underline, excluding, warn
 
@@ -30,6 +29,8 @@ alias_by_command: Dict[str, str] = {
     "traverse": "t"
 }
 
+command_by_alias: Dict[str, str] = {v: k for k, v in alias_by_command.items()}
+
 command_groups: List[Tuple[str, List[str]]] = [
     ("General topics",
      ["config", "file", "format", "help", "hooks", "version"]),
@@ -45,11 +46,16 @@ command_groups: List[Tuple[str, List[str]]] = [
      ["github"])
 ]
 
+commands_and_aliases = list(long_docs.keys()) + list(alias_by_command.keys())
+
 
 def get_help_description(command: str = None) -> str:
     usage_str = ''
-    if command and command in long_docs:
-        usage_str += fmt(textwrap.dedent(long_docs[command]))
+    if command and command in commands_and_aliases:
+        if command in long_docs:
+            usage_str += fmt(textwrap.dedent(long_docs[command]))
+        elif command in command_by_alias:
+            usage_str += fmt(textwrap.dedent(long_docs[command_by_alias[command]]))
     else:
         usage_str += get_short_general_usage() + '\n'
         if command:
@@ -109,7 +115,7 @@ class MacheteHelpAction(argparse.Action):
         # parser name (prog) is expected to be `git machete` or `git machete <command>`
         command_name = parser.prog.replace('git machete', '').strip()
         print(get_help_description(command_name))
-        parser.exit(status=None)
+        parser.exit(status=ExitCode.SUCCESS)
 
 
 def create_cli_parser() -> argparse.ArgumentParser:
@@ -240,7 +246,7 @@ def create_cli_parser() -> argparse.ArgumentParser:
 
     help_parser = subparsers.add_parser(
         'help', add_help=False, usage=argparse.SUPPRESS, parents=[common_args_parser])
-    help_parser.add_argument('topic_or_cmd', nargs='?', choices=list(short_docs.keys()))
+    help_parser.add_argument('topic_or_cmd', nargs='?', choices=commands_and_aliases)
 
     is_managed_parser = subparsers.add_parser(
         'is-managed',
@@ -453,6 +459,18 @@ def update_cli_opts_using_parsed_args(
         cli_opts.opt_no_interactive_rebase = True
 
 
+def update_cli_options_using_config_keys(
+        cli_opts: git_machete.options.CommandLineOptions,
+        git: GitContext
+) -> None:
+    machete_traverse_push_config_key = git.get_boolean_config_attr_or_none(key='machete.traverse.push')
+    if machete_traverse_push_config_key is not None:
+        if machete_traverse_push_config_key:
+            cli_opts.opt_push_tracked, cli_opts.opt_push_untracked = True, True
+        else:
+            cli_opts.opt_push_tracked, cli_opts.opt_push_untracked = False, False
+
+
 def set_utils_global_variables(
         cli_opts: git_machete.options.CommandLineOptions) -> None:
     if cli_opts.opt_color:
@@ -471,7 +489,7 @@ def get_local_branch_short_name_from_arg(
     return LocalBranchShortName.of(branch_from_arg.replace('refs/heads/', '')) if branch_from_arg else None
 
 
-def exit_script(status_code: Optional[int] = None, error: Optional[BaseException] = None) -> None:
+def exit_script(status_code: int, error: Optional[BaseException] = None) -> None:
     # Single point of exit is useful, because we can mock this method in tests
     # and verify that actual errors like MacheteException are raised with
     # appropriate messages. Otherwise it's not possible, because SystemError
@@ -493,22 +511,24 @@ def launch(orig_args: List[str]) -> None:
         parsed_cli: argparse.Namespace = cli_parser.parse_args(orig_args)
         parsed_cli_as_dict: Dict[str, str] = vars(parsed_cli)
 
+        update_cli_options_using_config_keys(cli_opts, git)
+
         update_cli_opts_using_parsed_args(cli_opts, parsed_cli)
         cli_opts.validate()
         set_utils_global_variables(cli_opts)
 
         if not orig_args:
             print(get_help_description())
-            exit_script(2)
+            exit_script(ExitCode.ARGUMENT_ERROR)
 
         cmd = parsed_cli.command
 
         if cmd == "help":
             print(get_help_description(parsed_cli.topic_or_cmd))
-            exit_script()
+            exit_script(ExitCode.SUCCESS)
         elif cmd == "version":
             version()
-            exit_script()
+            exit_script(ExitCode.SUCCESS)
 
         machete_client = MacheteClient(git)
 
@@ -664,7 +684,7 @@ def launch(orig_args: List[str]) -> None:
             machete_client.read_definition_file(perform_interactive_slide_out=should_perform_interactive_slide_out)
             branch = get_local_branch_short_name_from_arg_or_current_branch(cli_opts.opt_branch, git)
             if branch is None or branch not in machete_client.managed_branches:
-                exit_script(1)
+                exit_script(ExitCode.MACHETE_EXCEPTION)
         elif cmd == "list":
             category = parsed_cli.category
             if category == 'slidable-after' and 'branch' not in parsed_cli_as_dict:
@@ -811,13 +831,15 @@ def launch(orig_args: List[str]) -> None:
                 opt_no_interactive_rebase=cli_opts.opt_no_interactive_rebase,
                 opt_fork_point=cli_opts.opt_fork_point)
 
+    except EOFError:
+        exit_script(ExitCode.END_OF_FILE_SIGNAL)
     except KeyboardInterrupt:
-        exit_script(3)
+        exit_script(ExitCode.KEYBOARD_INTERRUPT)
     except (argparse.ArgumentError, argparse.ArgumentTypeError) as e:
         print(get_short_general_usage())
-        exit_script(2, e)
+        exit_script(ExitCode.ARGUMENT_ERROR, e)
     except MacheteException as e:
-        exit_script(1, e)
+        exit_script(ExitCode.MACHETE_EXCEPTION, e)
     except StopInteraction:
         pass
     finally:
