@@ -347,10 +347,15 @@ class GitContext:
         return self.__config_cached.get(key.lower())
 
     def get_boolean_config_attr(self, key: str, default_value: bool) -> bool:
+        if self.get_boolean_config_attr_or_none(key) is not None:
+            return self.get_boolean_config_attr_or_none(key)
+        return default_value
+
+    def get_boolean_config_attr_or_none(self, key: str) -> Optional[bool]:
         self.__ensure_config_loaded()
         if self.__config_cached.get(key.lower()) is not None:
             return self.__config_cached.get(key.lower()) == 'true'
-        return default_value
+        return None
 
     def set_config_attr(self, key: str, value: str) -> None:
         self._run_git("config", "--", key, value)
